@@ -6,8 +6,28 @@
 
 """
 Print detailed information about a process.
-
 Author: Giampaolo Rodola' <g.rodola@gmail.com>
+
+$ python examples/process_detail.py
+pid               820
+name              python
+exe               /usr/bin/python2.7
+parent            29613 (bash)
+cmdline           python examples/process_detail.py
+started           2014-41-27 03:41
+user              giampaolo
+uids              real=1000, effective=1000, saved=1000
+gids              real=1000, effective=1000, saved=1000
+terminal          /dev/pts/17
+cwd               /ssd/svn/psutil
+memory            0.1% (resident=10.6M, virtual=58.5M)
+cpu               0.0% (user=0.09, system=0.0)
+status            running
+niceness          0
+num threads       1
+I/O               bytes-read=0B, bytes-written=0B
+open files
+running threads   id=820, user-time=0.09, sys-time=0.0
 """
 
 import datetime
@@ -18,6 +38,9 @@ import sys
 import psutil
 
 
+POSIX = os.name == 'posix'
+
+
 def convert_bytes(n):
     symbols = ('K', 'M', 'G', 'T', 'P', 'E', 'Z', 'Y')
     prefix = {}
@@ -31,7 +54,7 @@ def convert_bytes(n):
 
 
 def print_(a, b):
-    if sys.stdout.isatty() and os.name == 'posix':
+    if sys.stdout.isatty() and POSIX:
         fmt = '\x1b[1;32m%-17s\x1b[0m %s' % (a, b)
     else:
         fmt = '%-15s %s' % (a, b)
@@ -49,8 +72,9 @@ def run(pid):
         sys.exit(str(sys.exc_info()[1]))
 
     try:
-        if p.parent:
-            parent = '(%s)' % p.parent.name
+        parent = p.parent()
+        if parent:
+            parent = '(%s)' % parent.name()
         else:
             parent = ''
     except psutil.Error:
@@ -62,7 +86,7 @@ def run(pid):
         round(pinfo['memory_percent'], 1),
         convert_bytes(pinfo['memory_info'].rss),
         convert_bytes(pinfo['memory_info'].vms))
-    children = p.get_children()
+    children = p.children()
 
     print_('pid', pinfo['pid'])
     print_('name', pinfo['name'])
@@ -71,11 +95,11 @@ def run(pid):
     print_('cmdline', ' '.join(pinfo['cmdline']))
     print_('started', started)
     print_('user', pinfo['username'])
-    if os.name == 'posix' and pinfo['uids'] and pinfo['gids']:
+    if POSIX and pinfo['uids'] and pinfo['gids']:
         print_('uids', 'real=%s, effective=%s, saved=%s' % pinfo['uids'])
-    if os.name == 'posix' and pinfo['gids']:
+    if POSIX and pinfo['gids']:
         print_('gids', 'real=%s, effective=%s, saved=%s' % pinfo['gids'])
-    if os.name == 'posix':
+    if POSIX:
         print_('terminal', pinfo['terminal'] or '')
     if hasattr(p, 'getcwd'):
         print_('cwd', pinfo['cwd'])
@@ -94,19 +118,19 @@ def run(pid):
     if children:
         print_('children', '')
         for child in children:
-            print_('', 'pid=%s name=%s' % (child.pid, child.name))
+            print_('', 'pid=%s name=%s' % (child.pid, child.name()))
 
     if pinfo['open_files'] != ACCESS_DENIED:
         print_('open files', '')
         for file in pinfo['open_files']:
-            print_('',  'fd=%s %s ' % (file.fd, file.path))
+            print_('', 'fd=%s %s ' % (file.fd, file.path))
 
     if pinfo['threads']:
         print_('running threads', '')
         for thread in pinfo['threads']:
-            print_('',  'id=%s, user-time=%s, sys-time=%s' % (
+            print_('', 'id=%s, user-time=%s, sys-time=%s' % (
                 thread.id, thread.user_time, thread.system_time))
-    if pinfo['connections'] != ACCESS_DENIED:
+    if pinfo['connections'] not in (ACCESS_DENIED, []):
         print_('open connections', '')
         for conn in pinfo['connections']:
             if conn.type == socket.SOCK_STREAM:
@@ -120,7 +144,7 @@ def run(pid):
                 rip, rport = '*', '*'
             else:
                 rip, rport = conn.raddr
-            print_('',  '%s:%s -> %s:%s type=%s status=%s' % (
+            print_('', '%s:%s -> %s:%s type=%s status=%s' % (
                 lip, lport, rip, rport, type, conn.status))
 
 
