@@ -17,21 +17,24 @@ import sys
 import threading
 import time
 import types
-import unittest
+
+if sys.version_info < (2, 7):
+    import unittest2 as unittest  # https://pypi.python.org/pypi/unittest2
+else:
+    import unittest
 
 import psutil
 import psutil._common
 
-from psutil._compat import PY3, callable, xrange
-from test_psutil import *
+from psutil._compat import callable, xrange
+from test_psutil import WINDOWS, POSIX, OSX, LINUX, SUNOS, TESTFN
+from test_psutil import (reap_children, supports_ipv6, safe_remove,
+                         get_test_subprocess)
 
 
 LOOPS = 1000
 TOLERANCE = 4096
 
-# disable cache for Process class properties
-psutil._common.cached_property.enabled = False
-
 
 class Base(unittest.TestCase):
     proc = psutil.Process(os.getpid())
@@ -77,7 +80,7 @@ class Base(unittest.TestCase):
                           % (rss2, rss3, difference))
 
     def get_mem(self):
-        return psutil.Process(os.getpid()).get_memory_info()[0]
+        return psutil.Process(os.getpid()).memory_info()[0]
 
     def call(self, *args, **kwargs):
         raise NotImplementedError("must be implemented in subclass")
@@ -136,22 +139,22 @@ class TestProcessObjectLeaks(Base):
     def test_status(self):
         self.execute('status')
 
-    def test_get_nice(self):
-        self.execute('get_nice')
+    def test_nice(self):
+        self.execute('nice')
 
     def test_set_nice(self):
-        niceness = psutil.Process(os.getpid()).get_nice()
+        niceness = psutil.Process(os.getpid()).nice()
         self.execute('set_nice', niceness)
 
-    def test_get_io_counters(self):
-        self.execute('get_io_counters')
+    def test_io_counters(self):
+        self.execute('io_counters')
 
-    def test_get_ionice(self):
-        self.execute('get_ionice')
+    def test_ionice(self):
+        self.execute('ionice')
 
     def test_set_ionice(self):
         if WINDOWS:
-            value = psutil.Process(os.getpid()).get_ionice()
+            value = psutil.Process(os.getpid()).ionice()
             self.execute('set_ionice', value)
         else:
             self.execute('set_ionice', psutil.IOPRIO_CLASS_NONE)
@@ -162,26 +165,26 @@ class TestProcessObjectLeaks(Base):
     def test_create_time(self):
         self.execute('create_time')
 
-    def test_get_num_threads(self):
-        self.execute('get_num_threads')
+    def test_num_threads(self):
+        self.execute('num_threads')
 
-    def test_get_num_handles(self):
-        self.execute('get_num_handles')
+    def test_num_handles(self):
+        self.execute('num_handles')
 
-    def test_get_num_fds(self):
-        self.execute('get_num_fds')
+    def test_num_fds(self):
+        self.execute('num_fds')
 
-    def test_get_threads(self):
-        self.execute('get_threads')
+    def test_threads(self):
+        self.execute('threads')
 
-    def test_get_cpu_times(self):
-        self.execute('get_cpu_times')
+    def test_cpu_times(self):
+        self.execute('cpu_times')
 
-    def test_get_memory_info(self):
-        self.execute('get_memory_info')
+    def test_memory_info(self):
+        self.execute('memory_info')
 
-    def test_get_ext_memory_info(self):
-        self.execute('get_ext_memory_info')
+    def test_memory_info_ex(self):
+        self.execute('memory_info_ex')
 
     def test_terminal(self):
         self.execute('terminal')
@@ -190,41 +193,43 @@ class TestProcessObjectLeaks(Base):
     def test_resume(self):
         self.execute('resume')
 
-    def test_getcwd(self):
-        self.execute('getcwd')
+    def test_cwd(self):
+        self.execute('cwd')
 
-    def test_get_cpu_affinity(self):
-        self.execute('get_cpu_affinity')
+    def test_cpu_affinity(self):
+        self.execute('cpu_affinity')
 
     def test_set_cpu_affinity(self):
-        affinity = psutil.Process(os.getpid()).get_cpu_affinity()
+        affinity = psutil.Process(os.getpid()).cpu_affinity()
         self.execute('set_cpu_affinity', affinity)
 
-    def test_get_open_files(self):
+    def test_open_files(self):
         safe_remove(TESTFN)  # needed after UNIX socket test has run
         f = open(TESTFN, 'w')
         try:
-            self.execute('get_open_files')
+            self.execute('open_files')
         finally:
             f.close()
 
     # OSX implementation is unbelievably slow
     @unittest.skipIf(OSX, "OSX implementation is too slow")
-    def test_get_memory_maps(self):
-        self.execute('get_memory_maps')
+    def test_memory_maps(self):
+        self.execute('memory_maps')
 
     @unittest.skipUnless(LINUX, "feature not supported on this platform")
-    def test_get_rlimit(self):
-        self.execute('get_rlimit', psutil.RLIMIT_NOFILE)
+    def test_rlimit(self):
+        self.execute('rlimit', psutil.RLIMIT_NOFILE)
 
     @unittest.skipUnless(LINUX, "feature not supported on this platform")
-    def test_get_rlimit(self):
-        limit = psutil.Process(os.getpid()).get_rlimit(psutil.RLIMIT_NOFILE)
+    def test_set_rlimit(self):
+        limit = psutil.Process(os.getpid()).rlimit(psutil.RLIMIT_NOFILE)
         self.execute('set_rlimit', psutil.RLIMIT_NOFILE, limit)
 
     # Linux implementation is pure python so since it's slow we skip it
     @unittest.skipIf(LINUX, "not worth being tested on Linux (pure python)")
-    def test_get_connections(self):
+    # Windows implementation is based on a single system-wide function
+    @unittest.skipIf(WINDOWS, "tested later")
+    def test_connections(self):
         def create_socket(family, type):
             sock = socket.socket(family, type)
             sock.bind(('', 0))
@@ -251,7 +256,7 @@ class TestProcessObjectLeaks(Base):
         if SUNOS:
             kind = 'inet'
         try:
-            self.execute('get_connections', kind=kind)
+            self.execute('connections', kind=kind)
         finally:
             for s in socks:
                 s.close()
@@ -298,13 +303,19 @@ class TestModuleFunctionsLeaks(Base):
         if callable(obj):
             obj(*args, **kwargs)
 
-    @unittest.skipUnless(
-        hasattr(psutil._psplatform, "get_num_cpus"),
-        "platform module does not expose a get_num_cpus() function")
     @unittest.skipIf(LINUX, "not worth being tested on POSIX (pure python)")
-    def test_NUM_CPUS(self):
-        psutil.get_num_cpus = psutil._psplatform.get_num_cpus
-        self.execute('get_num_cpus')
+    def test_cpu_count_logical(self):
+        psutil.cpu_count = psutil._psplatform.cpu_count_logical
+        self.execute('cpu_count')
+
+    @unittest.skipIf(LINUX, "not worth being tested on POSIX (pure python)")
+    def test_cpu_count_physical(self):
+        psutil.cpu_count = psutil._psplatform.cpu_count_physical
+        self.execute('cpu_count')
+
+    @unittest.skipIf(LINUX, "not worth being tested on POSIX (pure python)")
+    def test_boot_time(self):
+        self.execute('boot_time')
 
     @unittest.skipIf(POSIX, "not worth being tested on POSIX (pure python)")
     def test_pid_exists(self):
@@ -339,10 +350,13 @@ class TestModuleFunctionsLeaks(Base):
         self.execute('disk_io_counters')
 
     # XXX - on Windows this produces a false positive
-    @unittest.skipIf(WINDOWS,
-                     "XXX produces a false positive on Windows")
-    def test_get_users(self):
-        self.execute('get_users')
+    @unittest.skipIf(WINDOWS, "XXX produces a false positive on Windows")
+    def test_users(self):
+        self.execute('users')
+
+    @unittest.skipIf(POSIX, "not worth being tested on POSIX (pure python)")
+    def test_net_connections(self):
+        self.execute('net_connections')
 
 
 def test_main():
